from webob import Request, exc
from routr.exc import NoURLPatternMatched
from routr.utils import inject_args
import router

def wsgi_app(environ, start_response):
    request = Request(environ)
    status = '200 OK'
    try:
        trace = router.routes(request)
        view = trace.target
        args = inject_args(trace.target, trace.args, request=request)
        kwargs = trace.kwargs
        response = view(*args, **kwargs)
    except NoURLPatternMatched as e:
        status = '404 Not Found'
        response = 'The resource could not be located'
    except exc.HTTPException as e:
        status = '500 Internal server error'
        response = 'An error occurred while processing your request'
    response_headers = [('Content-type', 'application/json')]
    start_response(status, response_headers)
    yield response.encode()

if __name__ == '__main__':
    from wsgiref.simple_server import make_server

    httpd = make_server('localhost', 5555, wsgi_app)
    httpd.serve_forever()